use ansi_term::ANSIGenericString;
use ansi_term::Colour::RGB;
use std::env::current_dir;

pub const UNKNOWN_PATH: &str = "\u{2248}"; // "≈"
pub const PATH_COL: ansi_term::Colour = RGB(82, 82, 82);

fn home_dir() -> String {
    std::env::var("HOME").map_or_else(
        |_| "".to_string(),
        |path| path.to_string(),
    )
}

fn full_path() -> String {
	current_dir().map_or_else(
        |_| UNKNOWN_PATH.to_string(),
        |path| path.to_string_lossy().to_string(),
    )
}

fn replace_home(path: String) -> String {
    let homedir = home_dir();
    path.replace(&homedir, "~")
}

pub fn pwd(abbrev_home:bool) -> ANSIGenericString<'static, str> {
    let mut path = full_path();
    if abbrev_home {
        path = replace_home(path);
    }
    PATH_COL.italic().paint(path)
}